"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.agileWorkCreate = void 0;
const extensions_1 = require("../../../../../../../extensions");
exports.agileWorkCreate = new extensions_1.Command()
    .name("create")
    .description("Work Item Creation")
    .option("-f, --file <file>", "File containing backlog item template")
    .optionInteractive({
    shortName: "-f",
    longName: "--file",
    prompt: "What is the name of the file containing your backlog items?",
    choices: (serviceCollection) => __awaiter(void 0, void 0, void 0, function* () {
        const { contentService } = serviceCollection;
        const files = yield contentService.list();
        return [
            ...files.filter((filename) => filename.endsWith(".json") || filename.endsWith(".yml") || filename.endsWith(".yaml")),
            "other",
        ];
    }),
})
    .addAgileProviderOptions()
    .addAction((serviceCollection, options) => __awaiter(void 0, void 0, void 0, function* () {
    const { logger, getAgileService, backlogItemTemplateService, inputService } = serviceCollection;
    const agileService = getAgileService(options);
    // The command will give the user the option to choose between files in the working directory
    // If user selects 'other', they can then specify another file
    const inputFile = options.file === "other"
        ? yield inputService.askQuestion("What is the name of the file containing your backlog items?")
        : options.file;
    const template = yield backlogItemTemplateService.get(inputFile);
    if (template) {
        // Create Backlog Items
        const items = yield agileService.createBacklogItems(template.items);
        logger.logHeader("Created Items");
        items.forEach((item) => logBacklogItem(logger, item));
    }
}));
/**
 * Log a one-line backlog item description. Logs children recursively
 *
 * @param {Logger} logger Logger
 * @param {BacklogItem} item Backlog item
 * @param {string|undefined} parentId Parent ID if it has one
 */
function logBacklogItem(logger, item, parentId) {
    const { id, name, children, url } = item;
    const childOf = parentId ? ` (Child of ${parentId})` : "";
    const wrappedUrl = url ? ` (${url})` : "";
    logger.log(`${id}${childOf} - ${name}${wrappedUrl}`);
    if (children) {
        for (const child of children) {
            logBacklogItem(logger, child, id);
        }
    }
}
