"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.agileWorkImport = void 0;
const yaml_1 = require("yaml");
const constants_1 = require("../../../../../../../constants");
const extensions_1 = require("../../../../../../../extensions");
const filetype_1 = require("../../../../../../../models/general/filetype");
exports.agileWorkImport = new extensions_1.Command()
    .name("import")
    .description("Work Item Import")
    .optionInteractive({
    shortName: "-f",
    longName: "--format",
    description: "Format to save the file in",
    defaultValue: constants_1.FileConstants.defaultFileType,
    prompt: "What file format would you like to save the imported files in?",
    choices: Object.values(filetype_1.Filetype),
})
    .optionInteractive({
    shortName: "-d",
    longName: "--directory",
    description: "Directory to write to, which will be created if it does not exist.",
    defaultValue: constants_1.FileConstants.importDirectory,
    prompt: "Which directory would you like to save the imported file[s] to?",
})
    .addAgileProviderOptions()
    .addAction((serviceCollection, options) => __awaiter(void 0, void 0, void 0, function* () {
    const { logger, getAgileService, contentService } = serviceCollection;
    const agileService = getAgileService(options);
    const backlogItems = yield agileService.getBacklogItems();
    const fileExtension = options.format;
    logger.logHeader("Starting import...");
    backlogItems.forEach((backlogItem) => {
        var _a, _b;
        const filename = generateFileName(backlogItem, fileExtension);
        logger.debug(`Importing ${filename}`);
        const writeLocation = (_b = (_a = options.directory) === null || _a === void 0 ? void 0 : _a.toLowerCase().trim()) !== null && _b !== void 0 ? _b : constants_1.FileConstants.importDirectory;
        switch (fileExtension) {
            case ".yaml":
                contentService.set(filename, yaml_1.stringify(backlogItem), writeLocation);
                break;
            default:
                contentService.set(filename, JSON.stringify(backlogItem), writeLocation);
        }
    });
}));
/**
 * Generates a filename in a consistent compartmentalized way.
 *
 * @param {BacklogItem} item The backlog item to derive the filename from.
 * @param {string} extension The file extension to write.
 *
 * @returns {string} The filename.
 */
function generateFileName(item, extension) {
    return item.type.toLowerCase().concat("-", item.id || item.name.toLowerCase().replace(" ", "-"), extension);
}
