"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ServiceCollectionFactory = void 0;
const services_1 = require("../services");
const inquirerInputService_1 = require("../services/input/inquirerInputService");
const agileServiceFactory_1 = require("./agileServiceFactory");
const loggerFactory_1 = require("./loggerFactory");
const metricsFactory_1 = require("./metricsFactory");
const playbookServiceFactory_1 = require("./playbookServiceFactory");
const repoServiceFactory_1 = require("./repoServiceFactory");
/**
 * Factory for collections of services
 */
class ServiceCollectionFactory {
    /**
     * Create collection of shared services
     *
     * @returns {ServiceCollection} Service Collection
     */
    static create() {
        const logger = loggerFactory_1.LoggerFactory.get(services_1.LoggerProvider.Composite);
        const localFileStorageService = new services_1.FileStorageService(process.cwd(), logger);
        const parameterService = new services_1.ObjectService(localFileStorageService);
        const backlogItemTemplateService = new services_1.ObjectService(localFileStorageService);
        const contentService = new services_1.ObjectService(localFileStorageService);
        const inputService = new inquirerInputService_1.InquirerInputService(logger);
        return {
            getAgileService: (options) => agileServiceFactory_1.AgileServiceFactory.get(options, inputService, logger),
            getRepoService: (options) => repoServiceFactory_1.RepoServiceFactory.get(options, contentService),
            getPlaybookService: (options) => playbookServiceFactory_1.PlaybookServiceFactory.get(options, contentService, localFileStorageService),
            backlogItemTemplateService,
            parameterService,
            contentService,
            logger,
            inputService,
            metrics: metricsFactory_1.MetricsFactory.getIfRegistered(services_1.MetricsProvider.AppInsights),
        };
    }
}
exports.ServiceCollectionFactory = ServiceCollectionFactory;
