"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.BaseAgileService = void 0;
const constants_1 = require("../../constants");
const utils_1 = require("../../utils");
class BaseAgileService {
    constructor(config, inputService, logger) {
        this.config = config;
        this.inputService = inputService;
        this.logger = logger;
    }
    // Base functions
    createSprints(sprints) {
        return __awaiter(this, void 0, void 0, function* () {
            sprints = sprints || (yield this.generateSprints());
            return this.confirmAndCreateSprints(sprints);
        });
    }
    // Private functions
    generateSprints() {
        return __awaiter(this, void 0, void 0, function* () {
            const sprintConfig = yield this.createSprintConfig();
            const { startDate, lengthOfSprintInDays, numberOfSprints, daysBetweenSprints, sprintIndexStart } = sprintConfig;
            const indexStart = sprintIndexStart || utils_1.Config.getValue(constants_1.ConfigKey.AgileDefaultSprintStartIndex);
            const sprints = [];
            const timezoneOffset = new Date().getTimezoneOffset() * constants_1.NumberConstants.millisecondsInAMinute;
            let currentStartDate = new Date(Date.parse(startDate) + timezoneOffset);
            for (let i = indexStart; i < numberOfSprints + indexStart; i++) {
                const finishDate = utils_1.DateUtils.addDays(currentStartDate, lengthOfSprintInDays - 1);
                sprints.push({
                    name: `Sprint ${i}`,
                    startDate: currentStartDate,
                    finishDate,
                });
                currentStartDate = utils_1.DateUtils.addDays(finishDate, daysBetweenSprints + 1);
            }
            return sprints;
        });
    }
    createSprintConfig() {
        return __awaiter(this, void 0, void 0, function* () {
            // Get start date
            const startDate = yield this.inputService.askQuestion("What date would you like to start?", utils_1.DateUtils.toNumberDateString(utils_1.DateUtils.nextMonday()));
            // Get sprint length
            const sprintLength = yield this.inputService.askNumberQuestion("How long would you like your sprints to be?", utils_1.Config.getValue(constants_1.ConfigKey.AgileDefaultSprintLength));
            // Get sprint count
            const sprintCount = yield this.inputService.askNumberQuestion("How many sprints would you like?", utils_1.Config.getValue(constants_1.ConfigKey.AgileDefaultNumberOfSprints));
            // Get days between sprints
            const daysBetweenSprints = yield this.inputService.askNumberQuestion("How many days would you like between sprints?", utils_1.Config.getValue(constants_1.ConfigKey.AgileDefaultDaysBetweenSprints));
            return {
                lengthOfSprintInDays: sprintLength,
                numberOfSprints: sprintCount,
                daysBetweenSprints,
                startDate,
            };
        });
    }
    confirmAndCreateSprints(sprints) {
        return __awaiter(this, void 0, void 0, function* () {
            this.logger.log("The following sprints will be created:\n");
            sprints.forEach((sprint) => {
                const { name, startDate, finishDate } = sprint;
                this.logger.log(`${name}:\t${utils_1.DateUtils.toSimpleDateString(startDate)}\t${utils_1.DateUtils.toSimpleDateString(finishDate)}`);
            });
            if (yield this.inputService.confirmAction()) {
                this.logger.log("\nCreating sprints...");
                const createdSprints = yield this.createProviderSprints(sprints);
                this.logger.log("\nCreated sprints");
                return createdSprints;
            }
            else {
                this.logger.log("Operation cancelled");
                return [];
            }
        });
    }
}
exports.BaseAgileService = BaseAgileService;
