import { Logger, Properties } from "../../models";
/**
 * Logger for multiple destinations
 */
export declare class CompositeLogger implements Logger {
    private loggers;
    constructor(loggers: Logger[]);
    /**
     * Log a message at debug severity level for all child loggers
     *
     * @param {string} message Message to log at debug severity level
     * @param {Properties|undefined} properties Logging properties
     */
    debug(message: string, properties?: Properties): void;
    /**
     * Log a message at info severity level for all child loggers
     *
     * @param {string} message Message to log at info severity level
     * @param {Properties|undefined} properties Logging properties
     */
    log(message: string, properties?: Properties): void;
    /**
     * Log a message at warn severity level for all child loggers
     *
     * @param {string} message Message to log at warn severity level
     * @param {Properties|undefined} properties Logging properties
     */
    warn(message: string, properties?: Properties): void;
    /**
     * Log a message at error severity level for all child loggers
     *
     * @param {string} message Message to log at debug severity level
     * @param {Properties|undefined} properties Logging properties
     */
    error(message: string, properties?: Properties): void;
    /**
     * Log a header message to all child loggers
     *
     * @param {string} message Header message
     * @param {Properties|undefined} properties Logging properties
     */
    logHeader(message: string, properties?: Properties): void;
    /**
     * Adds default properties to all child loggers
     *
     * @param {Properties} properties Default properties to add
     */
    addDefaultProperties(properties: Properties): void;
}
