"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.CompositeLogger = void 0;
/**
 * Logger for multiple destinations
 */
class CompositeLogger {
    constructor(loggers) {
        this.loggers = loggers;
    }
    /**
     * Log a message at debug severity level for all child loggers
     *
     * @param {string} message Message to log at debug severity level
     * @param {Properties|undefined} properties Logging properties
     */
    debug(message, properties) {
        this.loggers.forEach((logger) => logger.debug(message, properties));
    }
    /**
     * Log a message at info severity level for all child loggers
     *
     * @param {string} message Message to log at info severity level
     * @param {Properties|undefined} properties Logging properties
     */
    log(message, properties) {
        this.loggers.forEach((logger) => logger.log(message, properties));
    }
    /**
     * Log a message at warn severity level for all child loggers
     *
     * @param {string} message Message to log at warn severity level
     * @param {Properties|undefined} properties Logging properties
     */
    warn(message, properties) {
        this.loggers.forEach((logger) => logger.warn(message, properties));
    }
    /**
     * Log a message at error severity level for all child loggers
     *
     * @param {string} message Message to log at debug severity level
     * @param {Properties|undefined} properties Logging properties
     */
    error(message, properties) {
        this.loggers.forEach((logger) => logger.error(message, properties));
    }
    /**
     * Log a header message to all child loggers
     *
     * @param {string} message Header message
     * @param {Properties|undefined} properties Logging properties
     */
    logHeader(message, properties) {
        this.loggers.forEach((logger) => logger.logHeader(message, properties));
    }
    /**
     * Adds default properties to all child loggers
     *
     * @param {Properties} properties Default properties to add
     */
    addDefaultProperties(properties) {
        this.loggers.forEach((logger) => logger.addDefaultProperties(properties));
    }
}
exports.CompositeLogger = CompositeLogger;
