"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.CodeWithPlaybookService = void 0;
const __1 = require("..");
const constants_1 = require("../../constants");
const samples_1 = require("../../samples");
const utils_1 = require("../../utils");
class CodeWithPlaybookService {
    constructor(repoService, contentService, storageService) {
        this.repoService = repoService;
        this.contentService = contentService;
        this.playbookRepoName = utils_1.Config.getValue(constants_1.ConfigKey.PlaybookRepoName);
        this.storageService = storageService;
    }
    getBacklogItemTemplates() {
        return __awaiter(this, void 0, void 0, function* () {
            const templatesList = yield this.repoService.listRepoItems(this.playbookRepoName, utils_1.Config.getValue(constants_1.ConfigKey.PlaybookWorkItemTemplatesPath), true);
            const backlogItemTemplates = samples_1.sampleWorkItemTemplates;
            const objectService = new __1.ObjectService(this.storageService);
            templatesList.forEach((repoItem) => {
                const { content, name } = repoItem;
                const template = objectService.parse(content, name);
                if (content) {
                    backlogItemTemplates.push(template);
                }
            });
            return backlogItemTemplates;
        });
    }
    getTemplates() {
        return __awaiter(this, void 0, void 0, function* () {
            const templatesName = constants_1.FileConstants.templatesFileName;
            const templatesFile = yield this.repoService.getRepoItem(this.playbookRepoName, templatesName, true);
            if (!templatesFile || !templatesFile.content) {
                throw new Error(`Couldn't find ${templatesName}, or it was empty.`);
            }
            const { name, content } = templatesFile;
            const objectService = new __1.ObjectService(this.storageService);
            const templates = objectService.parse(content, name);
            if (!Array.isArray(templates)) {
                throw new Error("Template file content should be an array");
            }
            return templates;
        });
    }
    getRepoItem(templateName, includeContent = false) {
        return __awaiter(this, void 0, void 0, function* () {
            const templates = yield this.getTemplates();
            const template = templates.find((target) => target.name === templateName);
            if (!template) {
                throw new Error(`No such template ${templateName}. Available templates are:\n${templates
                    .map((target) => target.name)
                    .join("\n")}`);
            }
            const { filePath, fileName } = template;
            const repoPath = `${filePath}/${fileName}`;
            return this.repoService.getRepoItem(this.playbookRepoName, repoPath, includeContent);
        });
    }
    downloadTemplate(localRelativePath, template) {
        return __awaiter(this, void 0, void 0, function* () {
            const { filePath, fileName } = template;
            const repoPath = [filePath, fileName].filter((value) => value && value.length).join("/");
            const { content } = yield this.repoService.getRepoItem(this.playbookRepoName, repoPath, true);
            if (!content) {
                throw new Error(`Couldn't get content from template ${template.name}`);
            }
            yield this.contentService.set(localRelativePath, content);
        });
    }
}
exports.CodeWithPlaybookService = CodeWithPlaybookService;
