"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.BaseRepoService = void 0;
const path_1 = require("path");
const models_1 = require("../../models");
class BaseRepoService {
    constructor(options, contentService) {
        this.options = options;
        this.contentService = contentService;
    }
    // Base functions
    downloadRepoItem(repo, path, branch, outputPath = process.cwd()) {
        return __awaiter(this, void 0, void 0, function* () {
            const repoItem = yield this.getRepoItem(repo, path, true, branch);
            yield this.writeRepoItem(repoItem, outputPath);
        });
    }
    listRepoItems(repo, path = "", includeContent = false, branch) {
        return __awaiter(this, void 0, void 0, function* () {
            const repoItem = yield this.getRepoItem(repo, path, false, branch);
            const { type, children } = repoItem;
            if (type !== models_1.RepoItemType.Directory || !children) {
                return [];
            }
            if (!includeContent) {
                return children;
            }
            return Promise.all(children.map((child) => {
                const { path: childPath } = child;
                return this.getRepoItem(repo, childPath, true, branch);
            }));
        });
    }
    // Private functions
    writeRepoItem(repoItem, outputPath) {
        return __awaiter(this, void 0, void 0, function* () {
            const { content, children, name, type } = repoItem;
            if (type === models_1.RepoItemType.Directory) {
                if (children) {
                    const subdirectory = path_1.join(outputPath, name);
                    yield Promise.all(children.map((item) => __awaiter(this, void 0, void 0, function* () { return this.writeRepoItem(item, subdirectory); })));
                }
            }
            else if (content) {
                this.contentService.set(name, content, outputPath);
            }
        });
    }
}
exports.BaseRepoService = BaseRepoService;
